<div align="center">
<img src="https://github.com/XayOn/pyrcrack/raw/develop/docs/pythonlovesaircrack.png" role=img>
</div>

PyrCrack is a Python library exposing a common aircrack-ng API.

!!! danger

    pyrcrack-ng is a **library**, you need heavy python knowledge to be able to
    use it. It's intended as a base to work upon.


# Status
--- | --- 
----- | ------- 
CI/CD | [![CI - Test](https://github.com/xayon/pyrcrack/actions/workflows/test.yml/badge.svg)](https://github.com/xayon/pyrcrack/actions/workflows/test.yml) [![CD - Build Package](https://github.com/xayon/pyrcrack/actions/workflows/release.yml/badge.svg)](https://github.com/xayon/pyrcrack/actions/workflows/release.yml) |
Package | [![PyPI - Version](https://img.shields.io/pypi/v/pyrcrack.svg?logo=pypi&label=PyPI&logoColor=gold)](https://pypi.org/project/pyrcrack/) [![PyPI - Downloads](https://img.shields.io/pypi/dm/pyrcrack.svg?color=blue&label=Downloads&logo=pypi&logoColor=gold)](https://pypi.org/project/pyrcrack/) [![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pyrcrack.svg?logo=python&label=Python&logoColor=gold)](https://pypi.org/project/pyrcrack/) |
Meta | [![code style - yapf](https://img.shields.io/badge/code%20style-yapf-000000.svg)](https://github.com/psf/black) [![types - Mypy](https://img.shields.io/badge/types-Mypy-blue.svg)](https://github.com/python/mypy) [![imports - isort](https://img.shields.io/badge/imports-isort-ef8336.svg)](https://github.com/pycqa/isort) 

# Contributors

![contributors](https://contrib.rocks/image?repo=xayon/pyrcrack)


## License

Pyrcrack is distributed under the terms of the [GPL2+](https://spdx.org/licenses/GPL2.html) license.

